Download the files associated with a URI.

get_data(uri, path, group, files=NULL, cache=TRUE, filter=TRUE, protocol="")

Arguments

uri

character. The URI of a dataset

path

character. The path to the Carob repo

group

character. group name

files

character. If not NULL these files are copied to the raw data folder; and uri is not used to get the data. This can be useful for datasets that do not have a URI or are not hosted on a website with a standard protocol for data retrieval such as dataverse or CKAN. It can also be useful to process local files before they are published. Files can either *all* have a http address, or they should *all* be on the local file system

cache

logical. if TRUE the data are only downloaded again if they are not locally available

filter

logical. if TRUE files that probably do not have the primary data are filtered out (files ending on .pdf, .doc(x), .json)

protocol

character; use "LSMS" for LSMS (usr_pwd) downloads

Value

character