Get a data processing function that is shared bewteen scripts. The function must exist in a file called _functions.R

get_function(name, path, group="")

Arguments

name

character. The name of the function

path

character. The path to the Carob repo

group

character. Optional, a group name

Value

function