Get the compiled location data for use in georeferencing. The dataset only exists after you have run make_carob.

get_locations(path, country = NULL)

Arguments

path

the path to the Carob repo

country

character or NULL to subset the data to a country

Value

data.frame