Read the meta-data file associated with a data set (from the associated json file) and check if the data set major and minor versions have changed.

get_metadata(uri, path, group, major, minor, ...)

Arguments

uri

character. The URI of the dataset

path

the path to your local copy of the Carob repo

group

optional, a group name

major

major version to check for, alerts when there's a new major version

minor

minor version to check for, alerts when there's a new minor version

...

additional named metadata values

Value

data.frame