Check if a file is an excel file. This is useful as there are files with extension .csv that are actually excel files, and there are files with extension .xls(x) that are actually .csv files

is_excel(f)

Arguments

f

character. filename

Value

logical