Read an excel file where the variable names are spread over more than one column (for other cases use read.excel.

read.excel.hdr(f, skip, hdr=1, fix_names=TRUE, lower=FALSE, ...)

Arguments

f

character (filename)

skip

non-negative integer. How many rows to skip to reach the values

hdr

positive integer. How many rows are used for the variable names

fix_names

logical. If TRUE variable names are made valid. Spaces and other characters such as parenthesis are replaced by a dot. Multiple dots are replaced by a single dot

lower

logical. If TRUE, returned column names are all in lowercase

...

additional arguments passed on to read_excel

.

Value

data.frame

See also