get_data.RdDownload the files associated with a URI.
get_data(uri, path, group, files=NULL, cache=TRUE, recursive=FALSE, filter=TRUE, protocol="")character. The URI of a dataset
character. The path to the Carob repo
character. group name
character. If not NULL these files are copied to the raw data folder; and uri is not used to get the data. This can be useful for datasets that do not have a URI or are not hosted on a website with a standard protocol for data retrieval such as dataverse or CKAN. It can also be useful to process local files before they are published. Files can either *all* have a http address, or they should *all* be on the local file system
logical. if TRUE the data are only downloaded again if they are not locally available
logical. if TRUE also return filenames in sub-directories
logical. if TRUE files that probably do not have the primary data are filtered out (files ending on .pdf, .doc(x), .json)
character; use "LSMS" for LSMS (usr_pwd) downloads
character