get_function.Rd
Get a data processing function that is shared bewteen scripts. The function must exist in a file called _functions.R
_functions.R
get_function(name, path, group="")
character. The name of the function
character. The path to the Carob repo
character. Optional, a group name
function