get_locations.Rd
Get the compiled location data for use in georeferencing. The dataset only exists after you have run make_carob.
make_carob
get_locations(path, country = NULL)
the path to the Carob repo
character or NULL to subset the data to a country
data.frame