on_github.RdGet a data.frame with the datasets that have been processed and are on the reagro/carob github site
on_github(uri=NULL)data.frame with columns:
uri: clean identifier (see simpleURI)
file: script path under the repository
(e.g. scripts/agronomy/doi_10.21223_HMMWZH.R), or empty if not found
note: "", "to be completed", "REJECTED",
"not found", or "not a valid URI"
When uri is supplied, one row is returned per input value (order and
duplicates are preserved).
if (FALSE) { # \dontrun{
all <- on_github()
test <- on_github(c("doi:10.21223/HMMWZH", "doi:10.7910/DVN/NDL2T3",
"doi_10.7910_DVN_NDL2T3.R"))
} # }