Get a data.frame with the datasets that have been processed and are on the reagro/carob github site

on_github(uri=NULL)

Arguments

uri

character. A standard URI to check for

Value

data.frame with variables: dataset, group, and pending

dataset is the identifier derived from the URI, see simpleURI. if a dataset is pending, the script is in the _pending folder and needs more work before it can be included.

Examples

if (FALSE) { # \dontrun{
all <- on_github()

test <- on_github("doi:10.25502/07RT-7A40/D")
} # }