Get the references associated with each dataset in a compilation.
get_references(x, path, format=TRUE)
Arguments
- x
data.frame
- path
the path to the Carob repo
- format
logical. If TRUE the reference is returned in a formatted form that can be used in a list of references in an article